package com.arrival.mobility.telemetryd.presets;

import org.bytedeco.javacpp.annotation.*;
import org.bytedeco.javacpp.tools.*;

import java.lang.annotation.Documented;
import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

@Properties(
    target = "com.arrival.mobility.telemetryd",
    global = "com.arrival.mobility.telemetryd.global.Telemetryd",
    helper = "com.arrival.mobility.telemetryd.helper.TelemetrydHelper",
    value = {
            @Platform(
                    value = { "macosx-x86_64" },
                    compiler = "cpp11",
                    define = {"SHARED_PTR_NAMESPACE std", "UNIQUE_PTR_NAMESPACE std"},
                    include = {
                            "test_functions.h"
                    }
            )
    }
)
public class Telemetryd implements InfoMapper {

    @Override
    public void map(InfoMap infoMap) {
        infoMap.put(new Info().enumerate());
        infoMap.put(new Info("std::string_view").pointerTypes("@StdString String").define());
        infoMap.put(new Info("std::function<void(MyStreamstream)>").pointerTypes("MyStreamCallback").define());
        infoMap.put(new Info("std::function<void(std::unique_ptr<MyStream>stream)>").pointerTypes("UniquePtrMyStreamCallback").define());
        infoMap.put(new Info("std::function<void(boolsuccess)>").pointerTypes("BooleanCallback").define());
    }

    @Documented
    @Retention(RetentionPolicy.RUNTIME)
    @Target({ElementType.METHOD, ElementType.PARAMETER})
    @Cast({"std::unique_ptr", "&&"}) @Adapter("UniquePtrAdapter")
    public @interface MoveUniquePtr {
        String value() default "";
    }
}
